@@ -388,7 +388,8 @@ bool ScNameDlg::AddPushed()
                 //	  in ein Token-Array uebersetzt werden?)
                 if ( 0 == pNewEntry->GetErrCode() )
                 {
-                    ScRangeData* pData = mpCurRangeName->findByName(aNewEntry);
+                    rtl::OUString aUpper( ScGlobal::pCharClass->upper( aNewEntry ) );
+                    ScRangeData* pData = mpCurRangeName->findByUpperName(aUpper);
                     if (pData)
                     {
                         pNewEntry->SetIndex(pData->GetIndex());
@@ -398,7 +399,7 @@ bool ScNameDlg::AddPushed()
                         mpImpl->Clear();
 
                     if ( !mpCurRangeName->insert( pNewEntry ) )
-                        delete pNewEntry;
+                        pNewEntry = NULL;
 
                     UpdateNames();
                     bSaved=false;
